//[mahjong-utils](../../../index.md)/[mahjongutils](../index.md)/[CalcContext](index.md)/[memo](memo.md)

# memo

[common]\
inline fun &lt;[T](memo.md)&gt; [memo](memo.md)(key: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?, calc: () -&gt; [T](memo.md)): [T](memo.md)
